@@ -31,7 +31,7 @@ class ManimLive:
             self.files[f]['number'] = file_numbers[i]
 
     def play_anim(self):
-        self.window = pyglet.window.Window(fullscreen=fullscreen)
+        self.window = pyglet.window.Window(fullscreen=self.fullscreen)
         player = pyglet.media.Player()
 
         for i in range(len(self.files)):
@@ -40,6 +40,9 @@ class ManimLive:
                     MediaLoad = pyglet.media.load(os.path.join(self.directory, self.files[f]['name']))
                     player.queue(MediaLoad)
 
+        player.pause()
+
+
         @self.window.event
         def on_draw():
             if player.source and player.source.video_format:
